@@ -33,20 +33,20 @@ NSC_DEITY | NSC_VAR | V_CHE,	"che",0,0,
 #ifdef	FALLOUT
 NSC_VAR | V_FALLOUT,	"fallout",0,0,
 #endif	/* FALLOUT */
-NSC_VAR | V_CIVIL,	"civil",0,EDV_CIV,
-NSC_VAR | V_MILIT,	"milit",0,EDV_MIL,
-NSC_VAR | V_SHELL,	"shell",0,EDV_SHL,
-NSC_VAR | V_GUN,	"gun",0,EDV_GUN,
-NSC_VAR | V_PETROL,	"petrol",0,EDV_PET,
-NSC_VAR | V_IRON,	"iron",0,0,
-NSC_VAR | V_DUST,	"dust",0,0,
-NSC_VAR | V_BAR,	"bar",0,EDV_BAR,
-NSC_VAR | V_FOOD,	"food",0,EDV_FOOD,
-NSC_VAR | V_OIL,	"oil",0,0,
-NSC_VAR | V_LCM,	"lcm",0,0,
-NSC_VAR | V_HCM,	"hcm",0,0,
-NSC_VAR | V_UW,		"uw",0,0,
-NSC_VAR | V_RAD,	"rad",0,EDV_LAST_COMM,
+NSC_ROUND | NSC_VAR | V_CIVIL,	"civil",0,EDV_CIV,
+NSC_ROUND | NSC_VAR | V_MILIT,	"milit",0,EDV_MIL,
+NSC_ROUND | NSC_VAR | V_SHELL,	"shell",0,EDV_SHL,
+NSC_ROUND | NSC_VAR | V_GUN,	"gun",0,EDV_GUN,
+NSC_ROUND | NSC_VAR | V_PETROL,	"petrol",0,EDV_PET,
+NSC_ROUND | NSC_VAR | V_IRON,	"iron",0,0,
+NSC_ROUND | NSC_VAR | V_DUST,	"dust",0,0,
+NSC_ROUND | NSC_VAR | V_BAR,	"bar",0,EDV_BAR,
+NSC_ROUND | NSC_VAR | V_FOOD,	"food",0,EDV_FOOD,
+NSC_ROUND | NSC_VAR | V_OIL,	"oil",0,0,
+NSC_ROUND | NSC_VAR | V_LCM,	"lcm",0,0,
+NSC_ROUND | NSC_VAR | V_HCM,	"hcm",0,0,
+NSC_ROUND | NSC_VAR | V_UW,		"uw",0,0,
+NSC_ROUND | NSC_VAR | V_RAD,	"rad",0,EDV_LAST_COMM,
 NSC_VAR | V_CDIST,	"c_dist",0,0,
 NSC_VAR | V_MDIST,	"m_dist",0,0,
 NSC_VAR | V_UDIST,	"u_dist",0,0,
@@ -84,7 +84,7 @@ NSC_UCHAR|fldoff(sctstr, sct_own),"owner",0,EDV_OWN,
 NSC_XCOORD|fldoff(sctstr, sct_x), "xloc",0,EDV_ID,
 NSC_YCOORD|fldoff(sctstr, sct_y), "yloc",0,EDV_ID,
 NSC_UCHAR|fldoff(sctstr, sct_type), "des",0,EDV_TYPE,
-NSC_UCHAR|fldoff(sctstr, sct_effic), "effic",0,EDV_EFF,
+NSC_ROUND|NSC_UCHAR|fldoff(sctstr, sct_effic), "effic",0,EDV_EFF,
 NSC_SHORT|fldoff(sctstr, sct_mobil), "mobil",0,0,
 NSC_UCHAR|fldoff(sctstr, sct_terr), "terr",0,0,
 NSC_UCHAR|fldoff(sctstr, sct_work), "work",0,0,
@@ -110,10 +110,10 @@ NSC_SHORT | fldoff(genitem, uid), "uid",0,EDV_ID,\
 NSC_XCOORD | fldoff(genitem, x), "xloc",0,EDV_XY,\
 NSC_YCOORD | fldoff(genitem, y), "yloc",0,EDV_XY,\
 NSC_UCHAR | fldoff(genitem, type), "type",0,EDV_TYPE,\
-NSC_UCHAR | fldoff(genitem, effic), "effic",0,EDV_EFF,\
+NSC_ROUND | NSC_UCHAR | fldoff(genitem, effic), "effic",0,EDV_EFF,\
 NSC_CHAR  | fldoff(genitem, mobil), "mobil",0,0,\
 NSC_SHORT | fldoff(genitem, sell), "sell",0,0,\
-NSC_SHORT | fldoff(genitem, tech), "tech",0,EDV_TECH,\
+NSC_ROUND | NSC_SHORT | fldoff(genitem, tech), "tech",0,EDV_TECH,\
 NSC_CHAR | fldoff(genitem, group), "group",0,0,\
 NSC_XCOORD | fldoff(genitem, opx), "opx",0,0,\
 NSC_YCOORD | fldoff(genitem, opy), "opy",0,0,\
@@ -242,25 +242,29 @@ NSC_XCOORD | fldoff(natstr, nat_xcap),"xcap",0,EDV_XY,
 NSC_YCOORD | fldoff(natstr, nat_ycap),"ycap",0,EDV_XY,
 NSC_DEITY | NSC_XCOORD | fldoff(natstr, nat_xorg),"xorg",0,0,
 NSC_DEITY | NSC_YCOORD | fldoff(natstr, nat_yorg),"yorg",0,0,
+#ifdef MAYBE_LATER
 NSC_CHAR | fldoff(natstr, nat_stat),"stat",0,0,
 NSC_CHAR | fldoff(natstr, nat_dayno),"dayno",0,0,
 #ifdef DEMANDUPDATE
 NSC_CHAR | fldoff(natstr, nat_update),"update",0,0,
 NSC_UCHAR | fldoff(natstr, nat_missed),"missed",0,0,
 #endif	/* DEMANDUPDATE */
+#endif /* MAYBE_LATER */
 NSC_USHORT | fldoff(natstr, nat_tgms),"tgms",0,0,
 NSC_USHORT | fldoff(natstr, nat_ann),"ann",0,0,
 NSC_USHORT | fldoff(natstr, nat_minused),"minused",0,0,
 NSC_SHORT | fldoff(natstr, nat_btu),"btu",0,0,
 NSC_LONG | fldoff(natstr, nat_reserve),"reserve",0,EDV_MIL,
 NSC_LONG | fldoff(natstr, nat_money),"money",0,EDV_MONEY,
+#ifdef MAYBE_LATER
 NSC_LONG | fldoff(natstr, nat_last_login),"last_login",0,0,
 NSC_LONG | fldoff(natstr, nat_last_logout),"last_logout",0,0,
 NSC_LONG | fldoff(natstr, nat_newstim),"newstim",0,0,
-NSC_FLOAT | fldoff(natstr, nat_level[0]),"level",4,EDV_LEVEL,
+#endif /* MAYBE_LATER */
+NSC_FLOAT | fldoff(natstr, nat_level[0]),"level",4,EDV_LEVEL, 
 /* NSC_SHORT | fldoff(natstr, nat_relate[0]),"relate",MAXNOC,0, */
 /* NSC_CHAR | fldoff(natstr, nat_priorities[0]),"priorities",39,0, */
-NSC_LONG | fldoff(natstr, nat_flags),"flags",0,0,
+/* NSC_LONG | fldoff(natstr, nat_flags),"flags",0,0, */
 0,	0,	0,0
 };
 
