@@ -15,6 +15,7 @@
 #include "nsc.h"
 #include "genitem.h"
 #include "optlist.h"
+#include "map.h"
 
 static u_short decodechr();
 static s_char *replace_colon();
@@ -157,34 +158,52 @@ pr_ca_val(cnum, ob, ca)
 		pr_async(cnum, "%hd", decode(cnum, ca->ca_code|NSC_OFF, ob, ob->ef_type));
 		break;
 	case NSC_UCHAR:
-		u = (u_char *)decodep(ca->ca_code, ob);
-		for (i = 0; !i || i < ca->ca_len; ++i, ++u)
-			pr_async(cnum, "%s%u", i?",":"", *u);
+		if (ca->ca_len) {
+			u = (u_char *)decodep(ca->ca_code, ob);
+			for (i = 0; !i || i < ca->ca_len; ++i, ++u)
+				pr_async(cnum, "%s%u", i?",":"", *u);
+		} else
+			pr_async(cnum, "%u", decode(cnum, ca->ca_code|NSC_OFF, ob, ob->ef_type));
 		break;
 	case NSC_SHORT:
-		h = (short *)decodep(ca->ca_code, ob);
-		for (i = 0; !i || i < ca->ca_len; ++i, ++h)
-			pr_async(cnum, "%s%hd", i?",":"", *h);
+		if (ca->ca_len) {
+			h = (short *)decodep(ca->ca_code, ob);
+			for (i = 0; !i || i < ca->ca_len; ++i, ++h)
+				pr_async(cnum, "%s%hd", i?",":"", *h);
+		} else
+			pr_async(cnum, "%hd", decode(cnum, ca->ca_code|NSC_OFF, ob, ob->ef_type));
 		break;
 	case NSC_USHORT:
-		us = (u_short *)decodep(ca->ca_code, ob);
-		for (i = 0; !i || i < ca->ca_len; ++i, ++us)
-			pr_async(cnum, "%s%hu", i?",":"", *us);
+		if (ca->ca_len) {
+			us = (u_short *)decodep(ca->ca_code, ob);
+			for (i = 0; !i || i < ca->ca_len; ++i, ++us)
+				pr_async(cnum, "%s%hu", i?",":"", *us);
+		} else
+			pr_async(cnum, "%hu", decode(cnum, ca->ca_code|NSC_OFF, ob, ob->ef_type));
 		break;
 	case NSC_INT:
-		in = (int *)decodep(ca->ca_code, ob);
-		for (i = 0; !i || i < ca->ca_len; ++i, ++in)
-			pr_async(cnum, "%s%d", i?",":"", *in);
+		if (ca->ca_len) {
+			in = (int *)decodep(ca->ca_code, ob);
+			for (i = 0; !i || i < ca->ca_len; ++i, ++in)
+				pr_async(cnum, "%s%d", i?",":"", *in);
+		} else
+			pr_async(cnum, "%d", decode(cnum, ca->ca_code|NSC_OFF, ob, ob->ef_type));
 		break;
 	case NSC_LONG:
-		l = (long *)decodep(ca->ca_code, ob);
-		for (i = 0; !i || i < ca->ca_len; ++i, ++l)
-			pr_async(cnum, "%s%ld", i?",":"", *l);
+		if (ca->ca_len) {
+			l = (long *)decodep(ca->ca_code, ob);
+			for (i = 0; !i || i < ca->ca_len; ++i, ++l)
+				pr_async(cnum, "%s%ld", i?",":"", *l);
+		} else
+			pr_async(cnum, "%ld", decode(cnum, ca->ca_code|NSC_OFF, ob, ob->ef_type));
 		break;
 	case NSC_FLOAT:
-		f = (float *)decodep(ca->ca_code, ob);
-		for (i = 0; !i || i < ca->ca_len; ++i, ++f)
-			pr_async(cnum, "%s%f", i?",":"", *f);
+		if (ca->ca_len) {
+			f = (float *)decodep(ca->ca_code, ob);
+			for (i = 0; !i || i < ca->ca_len; ++i, ++f)
+				pr_async(cnum, "%s%f", i?",":"", *f);
+		} else
+			pr_async(cnum, "%f", decode(cnum, ca->ca_code|NSC_OFF, ob, ob->ef_type));
 		break;
 	default:
 		pr_async(cnum, "ERROR");
@@ -310,3 +329,18 @@ prewrite_sync(oldob, newob)
 			prsync(oldob->own, newob, EDV_OWN);
 	}
 }
+
+pr_mapsct(x, y, des)
+	coord	x;
+	coord	y;
+	s_char	des;
+{
+	struct	mapsct	ms;
+
+	ms.map_x = x;
+	ms.map_y = y;
+	ms.map_des = des;
+	pr_sync("%d ", edbchr[EF_MAP].edb_class);
+	pr_vals(player->cnum, 1, &ms, edbchr[EF_MAP].edb_cf, 0, 0);
+	pr_sync("\n");
+}
